@@ -1,3 +1,4 @@
+use crate::api::managed_types::managed_buffer_api_node::unsafe_buffer_load_address;
 use elrond_wasm::{
     api::BlockchainApi,
     types::{
@@ -169,15 +170,25 @@ impl BlockchainApi for crate::ArwenApiImpl {
     }
 
     #[inline]
-    fn get_shard_of_address(&self, address: &Address) -> u32 {
+    fn get_shard_of_address_legacy(&self, address: &Address) -> u32 {
         unsafe { getShardOfAddress(address.as_ref().as_ptr()) as u32 }
     }
 
     #[inline]
-    fn is_smart_contract(&self, address: &Address) -> bool {
+    fn get_shard_of_address(&self, address: &ManagedAddress<Self>) -> u32 {
+        unsafe { getShardOfAddress(unsafe_buffer_load_address(address.get_raw_handle())) as u32 }
+    }
+
+    #[inline]
+    fn is_smart_contract_legacy(&self, address: &Address) -> bool {
         unsafe { isSmartContract(address.as_ref().as_ptr()) > 0 }
     }
 
+    #[inline]
+    fn is_smart_contract(&self, address: &ManagedAddress<Self>) -> bool {
+        unsafe { isSmartContract(unsafe_buffer_load_address(address.get_raw_handle())) > 0 }
+    }
+
     #[inline]
     fn get_caller_legacy(&self) -> Address {
         unsafe {
@@ -197,7 +208,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
         }
     }
 
-    fn get_balance(&self, address: &Address) -> BigUint<Self> {
+    fn get_balance_legacy(&self, address: &Address) -> BigUint<Self> {
         unsafe {
             let balance_handle = bigIntNew(0);
             bigIntGetExternalBalance(address.as_ref().as_ptr(), balance_handle);
@@ -205,8 +216,19 @@ impl BlockchainApi for crate::ArwenApiImpl {
         }
     }
 
+    fn get_balance(&self, address: &ManagedAddress<Self>) -> BigUint<Self> {
+        unsafe {
+            let balance_handle = bigIntNew(0);
+            bigIntGetExternalBalance(
+                unsafe_buffer_load_address(address.get_raw_handle()),
+                balance_handle,
+            );
+            BigUint::from_raw_handle(self.clone(), balance_handle)
+        }
+    }
+
     #[inline]
-    fn get_state_root_hash(&self) -> H256 {
+    fn get_state_root_hash_legacy(&self) -> H256 {
         unsafe {
             let mut res = H256::zero();
             getOriginalTxHash(res.as_mut_ptr());
@@ -216,7 +238,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
 
     #[inline]
     #[cfg(not(feature = "unmanaged-ei"))]
-    fn get_state_root_hash_managed(&self) -> elrond_wasm::types::ManagedByteArray<Self, 32> {
+    fn get_state_root_hash(&self) -> elrond_wasm::types::ManagedByteArray<Self, 32> {
         unsafe {
             let result_handle = mBufferNew();
             managedGetStateRootHash(result_handle);
@@ -225,7 +247,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
     }
 
     #[inline]
-    fn get_tx_hash(&self) -> H256 {
+    fn get_tx_hash_legacy(&self) -> H256 {
         unsafe {
             let mut res = H256::zero();
             getOriginalTxHash(res.as_mut_ptr());
@@ -235,7 +257,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
 
     #[inline]
     #[cfg(not(feature = "unmanaged-ei"))]
-    fn get_tx_hash_managed(&self) -> elrond_wasm::types::ManagedByteArray<Self, 32> {
+    fn get_tx_hash(&self) -> elrond_wasm::types::ManagedByteArray<Self, 32> {
         unsafe {
             let result_handle = mBufferNew();
             managedGetOriginalTxHash(result_handle);
@@ -269,7 +291,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
     }
 
     #[inline]
-    fn get_block_random_seed(&self) -> Box<[u8; 48]> {
+    fn get_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
         unsafe {
             let mut res = [0u8; 48];
             getBlockRandomSeed(res.as_mut_ptr());
@@ -279,7 +301,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
 
     #[inline]
     #[cfg(not(feature = "unmanaged-ei"))]
-    fn get_block_random_seed_managed(&self) -> elrond_wasm::types::ManagedByteArray<Self, 48> {
+    fn get_block_random_seed(&self) -> elrond_wasm::types::ManagedByteArray<Self, 48> {
         unsafe {
             let result_handle = mBufferNew();
             managedGetBlockRandomSeed(result_handle);
@@ -308,7 +330,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
     }
 
     #[inline]
-    fn get_prev_block_random_seed(&self) -> Box<[u8; 48]> {
+    fn get_prev_block_random_seed_legacy(&self) -> Box<[u8; 48]> {
         unsafe {
             let mut res = [0u8; 48];
             getPrevBlockRandomSeed(res.as_mut_ptr());
@@ -318,7 +340,7 @@ impl BlockchainApi for crate::ArwenApiImpl {
 
     #[inline]
     #[cfg(not(feature = "unmanaged-ei"))]
-    fn get_prev_block_random_seed_managed(&self) -> elrond_wasm::types::ManagedByteArray<Self, 48> {
+    fn get_prev_block_random_seed(&self) -> elrond_wasm::types::ManagedByteArray<Self, 48> {
         unsafe {
             let result_handle = mBufferNew();
             managedGetPrevBlockRandomSeed(result_handle);
